import pandas as pd
import matplotlib.pyplot as plt
import numpy as np
import seaborn as sns
data=pd.read_csv("data.csv")  #Reading the csv file...
print("Data is: ")
data.columns=['Num_of_Symptoms','Amount_of_Activity', 'Amount_of_sleep','Amount_of_food_consumed', 'Apetite', 'Skin_Reaction', 'Other_Factors']
data.Num_of_Symptoms = data.Num_of_Symptoms.astype(str)
print(data)  #Printing the data..

x=data.loc[:,"Amount_of_Activity":]    #Independent variable
y=data.Num_of_Symptoms                 #Depenedent variable
print("Ind: ",x)
print("Dep: ",y)

pd.plotting.scatter_matrix(data.loc[:,"Amount_of_Activity":"Other_Factors"],diagonal="kde") #Function to plot
plt.tight_layout()
plt.show() #Display the graph..

df=pd.read_csv("data.csv")
sns.lmplot(x="x2",y="x1",data=df) #x: x-axis content
sns.lmplot(x="x3",y="x1",data=df) #y: y-axis conteny
sns.lmplot(x="x4",y="x1",data=df)
sns.lmplot(x="x5",y="x1",data=df)
sns.lmplot(x="x6",y="x1",data=df)
sns.lmplot(x="x7",y="x1",data=df)

ax=data[['Num_of_Symptoms','Amount_of_Activity', 'Amount_of_sleep','Amount_of_food_consumed', 'Apetite', 'Skin_Reaction', 'Other_Factors']].plot()
ax.legend(loc='best') #set the legend
print(x.apply(np.std)) #Deviation in independent variables
plt.show()


# Write a python program to find the 
# minimum value of the function 𝑓(𝑥) = 3𝑥2 + 8 sin(𝑥) for −15 ≤ 𝑥 ≤ 15. 
# Also show the minimum value in the graph

import matplotlib.pyplot as plt

import numpy as np
from scipy import optimize as spop

def fn(x):
    return 3*x**2 + 8*np.sin(x)

x = np.linspace(-15, 15, 0.1)
plt.plot(x, fn(x))

res = spop.minimize(fn, x0=0)
print(res)
print("Minimum value of the function is: %.4f", res.x)
plt.plot(res.x, fn(res.x), 'o', label = 'Minimum value')
plt.title("Graph of the function")
plt.legend(["data", "minimum point"], loc="best")
plt.show()


#  Write a python program to plot the functions 𝑓(𝑥) = sin(𝑥2 + 𝑥) and 
# 𝑓(𝑥) = cos(𝑥2) ranging from −2𝜋 to 2𝜋 in 
# (a) a single frame and (b) side by side. Also mention the title and legends in the figure. 

import matplotlib.pyplot as plt
import numpy as np

n1 = 2 * -np.pi
n2 = 2 * np.pi
x = np.linspace(n1, n2, 256)
c = np.cos(x**2)
plt.plot(x,c)
plt.title("Cosine Function")
plt.show()

s = np.sin(x**2 + x)
plt.plot(x,s)
plt.title("sine(x^2 + x)")
plt.show()


# fitted linear and cubic interpolation into 30 intermediate points based on the following data
# x = [1, 2, 3, 4, 5, 6, 7, 8, 9, 10]
# y = [12, 43, 56,34,23,54,65,67,86,65]

import matplotlib.pyplot as plt

import numpy as np
from scipy.interpolate import interp1d

x = np.linspace(1, 10, 30)
y = (12, 43, 56,34,23,54,65,67,86,65)

f1 = interp1d(x, y, kind='linear')
f2 = interp1d(x, y, kind='cubic')

xnew = np.linspace(1, 10, 30)
plt.plot(x, y, 'o', xnew, f1(xnew), '-', xnew, f2(xnew), '--')
plt.legend(['data', 'linear', 'cubic'], loc='best')
plt.show()


import numpy as np
import matplotlib.pyplot as plt
from scipy.stats import multivariate_normal
from matplotlib import cm


def multivariate_normal(x, d, mean, cov):
    x_m = x - mean
    return (1. / (np.sqrt((2 * np.pi)**d * np.linalg.det(cov))) * np.exp(-(np.linalg.solve(cov, x_m).T.dot(x_m)) / 2))

def gen_surface(mean, cov, d):
    num_samples = 100                                                                     
    x1_s = np.linspace(-15, 15, num=num_samples)                                              

    x2_s = np.linspace(-15, 15, num=num_samples)
    x1, x2 = np.meshgrid(x1_s, x2_s)                                                      
    pdf = np.zeros((num_samples, num_samples))
    for i in range(num_samples):
        for j in range(num_samples):
            pdf[i,j] = multivariate_normal(np.matrix([[x1[i,j]], [x2[i,j]]]), d, mean, cov)
                                                                                        
    return x1, x2, pdf
d=2
r=0.7720
u=23
v=16
w=r*(u**(1/2))*(v**(1/2))                                                               
fig, (ax1) = plt.subplots(nrows=1, ncols=1, figsize=(10,10))                              
bivariate_mean = np.matrix([[3], [2]])                                                  
bivariate_covariance = np.matrix([[23, w], [w, 16]])                                    
x1, x2, p = gen_surface(bivariate_mean, bivariate_covariance, d)                   

con = ax1.contourf(x1, x2, p, 100, cmap=cm.YlGnBu)
ax1.set_xlabel('$x_1$', fontsize=13)                                                   
ax1.set_ylabel('$x_2$', fontsize=13)                                                    
ax1.axis([-15, 15, -15, 15])                                                            
ax1.set_aspect('equal')                                                                
ax1.set_title('The Required Plot', fontsize=12)
plt.show()                                                                              



import numpy as np
from scipy import linalg 

A = np.array([[23,12,9], [15,43,21],[11,14,26]])
B = np.array([6,-2,8])

det = linalg.det(A)

l,v = linalg.eig(A)

x = linalg.solve(A,B)

print("Determinant of A is: ", det)
print("Eigenvalues of A are: ", l)
print("Eigenvectors of A are: ", v)
print("Solution of the system of linear equations is: ", x)



from Tamako import Tamako
from plot_func import plot_func
from func_solv import func_solv
from fittedLinear import fittedLinear
from determinant_eigen import determinant_eigen
from independent_dependent import independent_dependent
from bivariate import bivariate

__title__ = "Tamako.py"
__version__ = "0.7"
__author__ = "BearTS"
__license__ = "MIT"
